| Title: | Deploy 'heatmaply' using 'shiny' |
|---|---|
| Description: | Access functionality of the 'heatmaply' package through 'Shiny UI'. |
| Authors: | Jonathan Sidi [aut, cre], Tal Galili [aut] |
| Maintainer: | Jonathan Sidi <[email protected]> |
| License: | GPL-2 | GPL-3 |
| Version: | 0.2.0 |
| Built: | 2026-05-14 07:28:27 UTC |
| Source: | https://github.com/yonicd/shinyheatmaply |
launch shiny app UI for heatmaply from R console
launch_heatmaply(obj, plotHeight = 800, viewerType = "paneViewer")launch_heatmaply(obj, plotHeight = 800, viewerType = "paneViewer")
obj |
data.frame or list of data.frames |
plotHeight |
numeric that sets the height of the plot output (default 800px) |
viewerType |
character of the viewer to be used to launch the app to c('paneViewer','dialogViewer','browserViewer') |
## Not run: if(interactive()){ data(mtcars) launch_heatmaply(mtcars) data(iris) launch_heatmaply(list('Example1'=mtcars,'Example2'=iris)) } ## End(Not run)## Not run: if(interactive()){ data(mtcars) launch_heatmaply(mtcars) data(iris) launch_heatmaply(list('Example1'=mtcars,'Example2'=iris)) } ## End(Not run)